###################################################################################################################################################
# Copyright 2015 Orchid Systems 
# -----------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an as is basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
# -------------------
# Updated: 2018/08/23 - includes system access to check to prevent script from running during D.I.C, Import, Export, etc.
###################################################################################################################################################


#################### Import Modules ###########################################
from accpac import *

import time
import datetime
import subprocess

###############################################################################

oedtl = None
arcusto = None
bInvalid = Continue

def onOpen():
	if rotoID != "OE0520":
		return 0	# don't do anything since the view is not OE0500 O/E sales order details.

	# Check system access to prevent running the script during Data Integrity Check, Import, Export, etc:
	if int(me.getAccess()) != 0:
		return 0.# do not run the script. System Access is not Normal.

	return Continue

def onBeforeCompose(e):
	global oedtl
	if e.views[0] is None:
		oedtl = None
	else:
		oedtl = e.views[0]

	return Continue

def onBeforeInsert():
	rvspyTrace("onBeforeInsert")

	global oedtl

	if oedtl is not None:
		# Validate against duplicate items.
		overrideCategory()

	return Continue


def onBeforeUpdate():
	rvspyTrace("onBeforeUpdate")

	global oedtl

	if oedtl is not None:
		# Validate against duplicate items.
		overrideCategory()

	return Continue


def openARCustOptionalFldView():
	rvspyTrace("openARCustOptionalFldView")

	global arcusto
	try:
		arcusto = openView("AR0400",1)
	except:
		arcusto = None


def overrideCategory():
	rvspyTrace("overrideCategory")

	# if the customer has the SAMPCAT optional field in their master record, then override the category with the value in that option field.

	global arcusto
	global oedtl

	sampcat = ""

	if (arcusto is None):
		openARCustOptionalFldView()

	if (arcusto is not None) and (oedtl is not None):

		# Get customer id from the OE Order Header.
		idcust = me.get("CUSTOMER")
		idcust = idcust.strip()

		# build filter string for the optional field view.
		sfilter = "IDCUST = \"" + idcust + "\" AND OPTFIELD = \"SAMPCAT\""
		rvspyTrace("overwriteCategory: " + sfilter)

		arcusto.recordClear()
		arcusto.browse(sfilter , 1)
		res = arcusto.fetch()
		if (res == 0):
			# optional field was found. Read the value.
			sampcat = arcusto.get("VALUE")
			sampcat = sampcat.strip()
			rvspyTrace("overwriteCategory: category value: " + sampcat)

		if (sampcat != ""):
			oedtl.recordClear()
			oedtl.browse("LINETYPE = 1",1)
			res = oedtl.fetch()
			while res == 0:
				try:
					oedtl.put("CATEGORY", sampcat)
					oedtl.update()
				except:
					rvspyTrace("unable to update item category")

				res = oedtl.fetch()

